==> kubernetes-client-4.10.3-sources.jar: io/fabric8/kubernetes/client/handlers/networking/v1/NetworkPolicyHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.networking.v1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.networking.v1.NetworkPolicyOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.networking.NetworkPolicy;
import io.fabric8.kubernetes.api.model.networking.NetworkPolicyBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class NetworkPolicyHandler implements ResourceHandler<NetworkPolicy, NetworkPolicyBuilder> {

  @Override
  public String getKind() {
    return NetworkPolicy.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "networking.k8s.io/v1";
      }

  @Override
  public NetworkPolicy create(OkHttpClient client, Config config, String namespace, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public NetworkPolicy replace(OkHttpClient client, Config config, String namespace, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public NetworkPolicy reload(OkHttpClient client, Config config, String namespace, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public NetworkPolicyBuilder edit(NetworkPolicy item) {
    return new NetworkPolicyBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NetworkPolicy item, Watcher<NetworkPolicy> watcher) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NetworkPolicy item, String resourceVersion, Watcher<NetworkPolicy> watcher) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NetworkPolicy item, ListOptions options, Watcher<NetworkPolicy> watcher) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public NetworkPolicy waitUntilReady(OkHttpClient client, Config config, String namespace, NetworkPolicy item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public NetworkPolicy waitUntilCondition(OkHttpClient client, Config config, String namespace, NetworkPolicy item, Predicate<NetworkPolicy> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}

==> kubernetes-client-5.0.3-sources.jar: io/fabric8/kubernetes/client/handlers/networking/v1/NetworkPolicyHandler.java <==

                                          

package io.fabric8.kubernetes.client.handlers.networking.v1;

import java.util.function.Predicate;

import io.fabric8.kubernetes.client.Config;
import io.fabric8.kubernetes.client.ResourceHandler;
import io.fabric8.kubernetes.client.Watch;
import io.fabric8.kubernetes.client.Watcher;
import io.fabric8.kubernetes.client.dsl.internal.networking.v1.NetworkPolicyOperationsImpl;

import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import okhttp3.OkHttpClient;

import io.fabric8.kubernetes.api.model.DeletionPropagation;
import io.fabric8.kubernetes.api.model.ListOptions;
import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicy;
import io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyBuilder;

import java.util.TreeMap;
import java.util.concurrent.TimeUnit;

public class NetworkPolicyHandler implements ResourceHandler<NetworkPolicy, NetworkPolicyBuilder> {

  @Override
  public String getKind() {
    return NetworkPolicy.class.getSimpleName();
  }

  @Override
  public String getApiVersion() {
        return "networking.k8s.io/v1";
      }

  @Override
  public NetworkPolicy create(OkHttpClient client, Config config, String namespace, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).create();
  }

  @Override
  public NetworkPolicy replace(OkHttpClient client, Config config, String namespace, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).replace(item);
  }

  @Override
  public NetworkPolicy reload(OkHttpClient client, Config config, String namespace, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).fromServer().get();
  }

  @Override
  public NetworkPolicyBuilder edit(NetworkPolicy item) {
    return new NetworkPolicyBuilder(item);
  }

  @Override
  public Boolean delete(OkHttpClient client, Config config, String namespace, DeletionPropagation propagationPolicy, NetworkPolicy item) {
    return new NetworkPolicyOperationsImpl(client, config, namespace).withItem(item).withPropagationPolicy(propagationPolicy).delete();
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NetworkPolicy item, Watcher<NetworkPolicy> watcher) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NetworkPolicy item, String resourceVersion, Watcher<NetworkPolicy> watcher) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(resourceVersion, watcher);
  }

  @Override
  public Watch watch(OkHttpClient client, Config config, String namespace, NetworkPolicy item, ListOptions options, Watcher<NetworkPolicy> watcher) {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).watch(options, watcher);
  }

  @Override
  public NetworkPolicy waitUntilReady(OkHttpClient client, Config config, String namespace, NetworkPolicy item, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilReady(amount, timeUnit);
  }

  @Override
  public NetworkPolicy waitUntilCondition(OkHttpClient client, Config config, String namespace, NetworkPolicy item, Predicate<NetworkPolicy> condition, long amount, TimeUnit timeUnit) throws InterruptedException {
    return new NetworkPolicyOperationsImpl(client, config).withItem(item).inNamespace(namespace).withName(item.getMetadata().getName()).waitUntilCondition(condition, amount, timeUnit);
  }
}
